==> xwiki-commons-extension-api-4.5-sources.jar: org/xwiki/extension/event/ExtensionUpgradedEvent.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.extension.event;

import org.xwiki.extension.ExtensionId;

/**
 * An event triggered when a extension has been upgraded.
 * 
 * @version $Id: 29e6b84b1edc1a2cf8c396825842e3c9f9d4bd2d $
 * @since 4.0M1
 */
public class ExtensionUpgradedEvent extends AbstractExtensionEvent
{
    /**
     * Matches all extensions.
     */
    public ExtensionUpgradedEvent()
    {
    }

    /**
     * Matches only the specified extension id or/and version.
     * 
     * @param extensionId the extension identifier
     * @param namespace the namespace on which the event happened
     */
    public ExtensionUpgradedEvent(ExtensionId extensionId, String namespace)
    {
        super(extensionId, namespace);
    }
}

==> xwiki-commons-extension-api-7.1.4-sources.jar: org/xwiki/extension/event/ExtensionUpgradedEvent.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.extension.event;

import org.xwiki.extension.ExtensionId;

/**
 * An event triggered when a extension has been upgraded.
 * <p>
 * The event also send the following parameters:
 * </p>
 * <ul>
 * <li>source: the related new {@link org.xwiki.extension.InstalledExtension} instance</li>
 * <li>data: the related previous {@link org.xwiki.extension.InstalledExtension} instance</li>
 * </ul>
 *
 * @version $Id: 944eb2b98511d4f194713c8782d07946d66ed61b $
 * @since 4.0M1
 */
public class ExtensionUpgradedEvent extends AbstractExtensionEvent
{
    /**
     * Matches all extensions.
     */
    public ExtensionUpgradedEvent()
    {
    }

    /**
     * Matches only the specified extension id or/and version.
     *
     * @param extensionId the extension identifier
     * @param namespace the namespace on which the event happened
     */
    public ExtensionUpgradedEvent(ExtensionId extensionId, String namespace)
    {
        super(extensionId, namespace);
    }
}
